pub struct Config {
pub output: OutputMode,
pub theme: HashMap<Level, Style>,
}Expand description
Configuration for the XMT logger.
Fields
output: OutputModeThe output mode.
Used to determine how to print values emitted with xmt::out!.
theme: HashMap<Level, Style>The theme to use for the output.
The theme is not taken into account when not outputing to a TTY.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn with_style(self, level: Level, style: Style) -> Self
pub fn with_style(self, level: Level, style: Style) -> Self
Set the style for a given log level.
Overwrites any previously set style for the given level.
Examples
use xmt::{Color, Config, Level, Style};
Config::default().with_style(Level::Normal, Style::new(Color::Red));Sourcepub fn with_json_output(self) -> Self
pub fn with_json_output(self) -> Self
Enables JSON output
Mutually exclusive with xmt::Config::with_tree_output.
Sourcepub fn with_tree_output(self) -> Self
pub fn with_tree_output(self) -> Self
Enables tree output
Mutually exclusive with xmt::Config::with_json_output.